@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 12416 2020-07-23 06:40:43Z Lavender $
+# $Id: Patch.py 12627 2020-11-26 10:59:32Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-07-23 15:40:43 +0900 (週四, 23 七月 2020) $
-# $Revision: 12416 $
+# $Date: 2020-11-26 19:59:32 +0900 (週四, 26 十一月 2020) $
+# $Revision: 12627 $
 #
 # Contributors:
 #  Bear
@@ -242,6 +242,29 @@ def attachURLs(settings, urlpatterns):
             url(r'^metrics/image/', getStatsdImage, name='getStatsdImage'),
         )
         
+    addCloudSMSAPIUrl = False
+    if hasattr(settings ,'IUNO_CLOUD_ENABLE'):
+        if settings.IUNO_CLOUD_ENABLE:
+            if hasattr(settings ,'IUNO_CLOUD_SERVICES'):
+                services = settings.IUNO_CLOUD_SERVICES
+                if 'sms' in services:
+                    addCloudSMSAPIUrl = True
+            else:
+                addCloudSMSAPIUrl = True
+                
+    if addCloudSMSAPIUrl:
+        from Iuno.cloud.sms.views import callAPISMS
+        urlpatterns += patterns('',
+            url(r'^sms/api/send/', callAPISMS, name='callAPISMS'),
+        )
+        
+    if hasattr(settings ,  'IUNO_CLOUD_SMS_CLIENT_ENABLE'):
+        from Iuno.cloud.sms.views import sendSMSCaptcha
+        urlpatterns += patterns('',
+            url(r'^sms/captcha/send/', sendSMSCaptcha, name='sendSMSCaptcha'),
+        )
+        
+        
     addTestUrl = False
     if hasattr(settings ,'IUNO_TEST_ENABLE'):
         addTestUrl = settings.IUNO_TEST_ENABLE
