@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12303 2020-06-03 06:22:10Z Lavender $
+# $Id: __init__.py 12341 2020-06-11 14:59:06Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-06-03 15:22:10 +0900 (週三, 03 六月 2020) $
-# $Revision: 12303 $
+# $Date: 2020-06-11 23:59:06 +0900 (週四, 11 六月 2020) $
+# $Revision: 12341 $
 
 from __future__ import print_function
 
@@ -752,9 +752,11 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'Iuppiter.extension',
         'Iuno.deploy',
         'Iuno.ban',
+        'Iuno.maintenance',
     )
     ADDING_MIDDLEWARE = [
         'Iuno.ban.middleware.BanSpamMiddleware',
+        'Iuno.maintenance.middleware.MaintenanceMiddleware',
     ]
     installed = settingsDict['INSTALLED_APPS']
     keys = [k for k in installed if k.startswith('django.contrib')]
