@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11974 2020-03-11 17:58:14Z Lavender $
+# $Id: __init__.py 12447 2020-08-06 05:22:08Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-12 02:58:14 +0900 (週四, 12 三月 2020) $
-# $Revision: 11974 $
+# $Date: 2020-08-06 14:22:08 +0900 (週四, 06 八月 2020) $
+# $Revision: 12447 $
 
 import logging
 import traceback
@@ -120,8 +120,8 @@ class EmailBackend(BaseEmailBackend):
                 'app': utf8(app)
             })
             link = '%sapp/login/' % self.domain
-            result = urlopen(link, data=data).read()
-            result = self.parseResult(result)
+            result = urlopen(link, data=data.encode()).read()
+            result = self.parseResult(result.decode()[1:-2])
             return result['token']
         except Exception as e:
             raise
@@ -215,9 +215,8 @@ class EmailBackend(BaseEmailBackend):
 
                 try:
                     link = '%sapp/mail/' % self.domain
-                    result = urlopen(link, data=data).read()
-                    result = self.parseResult(result)
-                    return result
+                    result = urlopen(link, data=data.encode()).read()
+                    result = self.parseResult(result[1:-2])
                 except Exception as e:
                     raise
         except Exception as e:
