@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 12628 2020-11-26 12:39:59Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,16 +12,29 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2020-11-26 21:39:59 +0900 (週四, 26 十一月 2020) $
+# $Revision: 12628 $
 
 import collections
 import json
 
+import requests
+
 from six.moves import urllib_parse, urllib_request, urllib_error
 
-
+from Iuno import require
 from Iuppiter.Encoding import utf8
+from Iuppiter.DjangoUtil import extendInstalledApps
+
+def attachSettings(settingsLocals, backends, preferred, config):
+    # IUNO_CLOUD_SMS_ADMIN = True 時加入
+    extendInstalledApps(settingsLocals, (
+        'Iuno.cloud.sms',
+    ))
+    
+    if "IUNO_CLOUD_SMS_CLIENT_ENABLE" in settingsLocals: # 這個不用
+        require("IUNO_CLOUD_SMS_CLIENT_URL", settingsLocals) # 這個預設 api.nuwainfo.com
+        require("IUNO_CLOUD_SMS_CLIENT_TOKEN", settingsLocals) # 這個 require，如果 IUNO_CLOUD_SMS_ADMIN = True 則不用
 
 class SMS(object):
 
@@ -59,7 +72,7 @@ class SMS(object):
                 ('username', username if username else 'nuwa'),
                 ('password', password if password else 'nuwa25025529'),
                 ('method', "2"),
-                ('sms_msg', utf8(message)),
+                ('sms_msg', message),
                 ('send_date', date),
                 ('hour', hour),
                 ('min', min),
@@ -69,7 +82,7 @@ class SMS(object):
                 ('username', username if username else 'nuwa'),
                 ('password', password if password else 'nuwa25025529'),
                 ('method', "1"),
-                ('sms_msg', utf8(message))
+                ('sms_msg', message)
             ]
 
         self.result = None
@@ -88,18 +101,19 @@ class SMS(object):
             phoneData = ('phone', str(phones))
             postData = self.postData
             postData.append(phoneData)
+            url = 'http://sms-get.com/api_send.php?' + urllib_parse.urlencode(postData)
             
             try:
-                result = urllib_request.urlopen(
-                            'http://sms-get.com/api_send.php?' + \
-                            urllib_parse.urlencode(postData)
-                         )
+                result = requests.get(url)
+                result = json.loads(result.text)
             except Exception as e:
-                result = '{"stats":false,'+ \
-                         '"error_code":"-999",' + \
-                         '"error_msg": "%s"}' % str(e)
-                         
-            self.resultDetails.append(json.loads(result.read()))
+                result = {
+                    "stats": False,
+                    "error_code": -999,
+                    "error_msg": str(e),
+                }
+             
+            self.resultDetails.append(result)
 
         self.setResult()
         
