@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12000 2020-03-24 16:39:06Z Trista $
+# $Id: __init__.py 12485 2020-08-27 10:15:37Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2020-03-25 01:39:06 +0900 (週三, 25 三月 2020) $
-# $Revision: 12000 $
+# $Author: Lavender $ (last)
+# $Date: 2020-08-27 19:15:37 +0900 (週四, 27 八月 2020) $
+# $Revision: 12485 $
 
 import os
 import sys
@@ -86,7 +86,7 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
         authenticationBackends.append('social_core.backends.google.GoogleOAuth2')
             
     if enableYahoo:
-        authenticationBackends.append('social_core.backends.yahoo.YahooOpenId')
+        authenticationBackends.append('social_core.backends.yahoo.YahooOAuth2')
         
     if enableLive:
         authenticationBackends.append('social_core.backends.live.LiveOAuth2')
@@ -163,6 +163,10 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
         require('SOCIAL_AUTH_GOOGLE_OAUTH2_KEY', settingsDict)
         require('SOCIAL_AUTH_GOOGLE_OAUTH2_SECRET', settingsDict)
         
+    if enableYahoo:
+        require('SOCIAL_AUTH_YAHOO_OAUTH2_KEY', settingsDict)
+        require('SOCIAL_AUTH_YAHOO_OAUTH2_SECRET', settingsDict)
+        
     if enableLive:
         socailAuthSettingsDefaults['SOCIAL_AUTH_LIVE_SCOPE'] = \
             ['wl.basic', 'wl.emails']
