@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12432 2020-07-29 12:27:09Z Lavender $
+# $Id: views.py 12541 2020-10-07 17:14:18Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-07-29 21:27:09 +0900 (週三, 29 七月 2020) $
-# $Revision: 12432 $ 
+# $Date: 2020-10-08 02:14:18 +0900 (週四, 08 十月 2020) $
+# $Revision: 12541 $ 
 
 import json
 import logging
@@ -58,7 +58,7 @@ from Iuno.shop import buildAPIForm
 from Iuno.shop.models import (
     ECPayTrade, AllPayTrade, SpgatewayTrade, CathaybkCreditTrade,
     ECPayLogisticTrade, OrderOrdererAddress, OrdererAddress, 
-    BonusSettings, BonusRecord, Bonus, calcReceiveBouns, getATMInfo)
+    BonusSettings, BonusRecord, Bonus, calcReceiveBouns, getATMInfo, TradeSession)
 from Iuno.shop.Util import createCheckValue
 
 _PaymentDetailsView = get_class('checkout.views', 'PaymentDetailsView')
@@ -1072,6 +1072,13 @@ def sendPaymentForm(request):
         form = encryptor.decrypt(d)
         if six.PY3:
             form = form.decode()
+            
+        TradeSession.objects.update_or_create(
+            basket=request.basket,
+            defaults={
+                'sessionKey': request.COOKIES.get(settings.SESSION_COOKIE_NAME),
+            }
+        )
         
         return render(
                 request, 
@@ -1429,6 +1436,7 @@ class SuccessResponseView2(_PaymentDetailsView):
                 self.basketId = int(request.POST.get('basketId'))
 
             if self.request.session.get('logisticMap'):
+                self.request.basket = self.loadFrozenBasket(self.basketId)
                 submission = super(
                     SuccessResponseView2, self).build_submission(**kwargs)
                 form = buildAPIForm(
